@@ -15,7 +15,7 @@ use Sub::Identify ();
 {
 	package MooseX::KavorkaInfo;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.000_10';
+	our $VERSION   = '0.000_11';
 	
 	sub import
 	{
@@ -36,7 +36,7 @@ use Sub::Identify ();
 {
 	package MooseX::KavorkaInfo::Trait::Method;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.000_10';
+	our $VERSION   = '0.000_11';
 	
 	use Moose::Role;
 	
@@ -66,7 +66,7 @@ use Sub::Identify ();
 {
 	package MooseX::KavorkaInfo::Trait::WrappedMethod;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.000_10';
+	our $VERSION   = '0.000_11';
 	
 	use Moose::Role;
 	with 'MooseX::KavorkaInfo::Trait::Method';
@@ -101,14 +101,14 @@ MooseX::KavorkaInfo - make Kavorka->info available through Moose meta objects
    package Foo {
       use Moose;
       use MooseX::KavorkaInfo;
-      use Kavorka;
+      use Kavorka qw( -default -modifiers );
       method xxx (Int $x) { return $x ** 3 }
    }
    
    package Foo::Verbose {
       use Moose;
       use MooseX::KavorkaInfo;
-      use Kavorka;
+      use Kavorka qw( -default -modifiers );
       extends "Foo";
       before xxx { warn "Called xxx" }
    }
